==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution.md <==
# AmazonCloudFrontDownloadDistribution


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')
```



| Illustration | AmazonCloudFrontDownloadDistribution | AmazonCloudFrontDownloadDistributionCard | AmazonCloudFrontDownloadDistributionGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution.png) | ![illustration for AmazonCloudFrontDownloadDistribution](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution.Local.png) | ![illustration for AmazonCloudFrontDownloadDistributionCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistributionCard.Local.png) | ![illustration for AmazonCloudFrontDownloadDistributionGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistributionGroup.Local.png) |




## AmazonCloudFrontDownloadDistribution

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistribution
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistribution('AmazonCloudFrontDownloadDistribution', 'Amazon Cloud Front Download Distribution', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistribution
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistribution('AmazonCloudFrontDownloadDistribution', 'Amazon Cloud Front Download Distribution', 'an optional tech label')
@enduml
```

## AmazonCloudFrontDownloadDistributionCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistributionCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistributionCard('AmazonCloudFrontDownloadDistributionCard', 'Amazon Cloud Front Download Distribution Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistributionCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistributionCard('AmazonCloudFrontDownloadDistributionCard', 'Amazon Cloud Front Download Distribution Card', 'an optional description')
@enduml
```

## AmazonCloudFrontDownloadDistributionGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistributionGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistributionGroup('AmazonCloudFrontDownloadDistributionGroup', 'Amazon Cloud Front Download Distribution Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistributionGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistributionGroup('AmazonCloudFrontDownloadDistributionGroup', 'Amazon Cloud Front Download Distribution Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution.md <==
# AmazonCloudFrontDownloadDistribution


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')
```



| Illustration | AmazonCloudFrontDownloadDistribution | AmazonCloudFrontDownloadDistributionCard | AmazonCloudFrontDownloadDistributionGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution.png) | ![illustration for AmazonCloudFrontDownloadDistribution](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution.Local.png) | ![illustration for AmazonCloudFrontDownloadDistributionCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistributionCard.Local.png) | ![illustration for AmazonCloudFrontDownloadDistributionGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistributionGroup.Local.png) |




## AmazonCloudFrontDownloadDistribution

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistribution
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistribution('AmazonCloudFrontDownloadDistribution', 'Amazon Cloud Front Download Distribution', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistribution
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistribution('AmazonCloudFrontDownloadDistribution', 'Amazon Cloud Front Download Distribution', 'an optional tech label')
@enduml
```

## AmazonCloudFrontDownloadDistributionCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistributionCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistributionCard('AmazonCloudFrontDownloadDistributionCard', 'Amazon Cloud Front Download Distribution Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistributionCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistributionCard('AmazonCloudFrontDownloadDistributionCard', 'Amazon Cloud Front Download Distribution Card', 'an optional description')
@enduml
```

## AmazonCloudFrontDownloadDistributionGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistributionGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistributionGroup('AmazonCloudFrontDownloadDistributionGroup', 'Amazon Cloud Front Download Distribution Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontDownloadDistributionGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontDownloadDistribution')

' renders the element
AmazonCloudFrontDownloadDistributionGroup('AmazonCloudFrontDownloadDistributionGroup', 'Amazon Cloud Front Download Distribution Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
